@@ -220,7 +220,7 @@ A Latex representation of the dimensionality may be obtained in the following fa
     >>> mass = 50 * pq.kg
     >>> weight = mass*g
     >>> print weight.dimensionality.latex
-    $\mathrm{\\frac{kg{\\cdot}m}{s^{2}}}$
+    $\\mathrm{\\frac{kg{\\cdot}m}{s^{2}}}$
     >>> weight.units = pq.N
     >>> print weight.dimensionality.latex
     $\\mathrm{N}$
@@ -265,11 +265,9 @@ units, they should still conform to valid python expressions.
 
 """
 
-from __future__ import absolute_import
 
-from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
+from . import _version
+__version__ = _version.get_versions()['version']
 
 from .registry import unit_registry
 
