@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
-
+import unittest
 from .. import units as pq
+from .. import quantity
 from .common import TestCase
 
 
@@ -15,6 +15,44 @@ class TestConversion(TestCase):
     def test_rescale(self):
         for u in ('ft', 'feet', pq.ft):
             self.assertQuantityEqual((10*pq.m).rescale(u), 32.80839895 * pq.ft)
+            
+    def test_rescale_preferred(self):
+        quantity.PREFERRED = [pq.mV, pq.pA]
+        q = 10*pq.V
+        self.assertQuantityEqual(q.rescale_preferred(), q.rescale(pq.mV))
+        q = 5*pq.A
+        self.assertQuantityEqual(q.rescale_preferred(), q.rescale(pq.pA))
+        quantity.PREFERRED = []
+    
+    def test_rescale_preferred_failure(self):
+        quantity.PREFERRED = [pq.pA]
+        q = 10*pq.V
+        try:
+            self.assertQuantityEqual(q.rescale_preferred(), q.rescale(pq.mV))
+        except:
+            self.assertTrue(True)
+        else:
+            self.assertTrue(False)
+        quantity.PREFERRED = []
+    
+    def test_rescale_noargs(self):
+        quantity.PREFERRED = [pq.mV, pq.pA]
+        q = 10*pq.V
+        self.assertQuantityEqual(q.rescale(), q.rescale(pq.mV))
+        q = 5*pq.A
+        self.assertQuantityEqual(q.rescale(), q.rescale(pq.pA))
+        quantity.PREFERRED = []
+    
+    def test_rescale_noargs_failure(self):
+        quantity.PREFERRED = [pq.pA]
+        q = 10*pq.V
+        try:
+            self.assertQuantityEqual(q.rescale_preferred(), q.rescale(pq.mV))
+        except:
+            self.assertTrue(True)
+        else:
+            self.assertTrue(False)
+        quantity.PREFERRED = []
 
     def test_compound_reduction(self):
         pc_per_cc = pq.CompoundUnit("pc/cm**3")
