@@ -1,8 +1,6 @@
 """
 """
-from __future__ import absolute_import
 
-import sys
 import weakref
 
 import numpy
@@ -216,15 +214,6 @@ class UnitQuantity(Quantity):
     def __rtruediv__(self, other):
         return self.view(Quantity).__rtruediv__(other)
 
-    if sys.version_info[0] < 3:
-        @with_doc(Quantity.__div__, use_header=False)
-        def __div__(self, other):
-            return self.view(Quantity).__div__(other)
-
-        @with_doc(Quantity.__rdiv__, use_header=False)
-        def __rdiv__(self, other):
-            return self.view(Quantity).__rdiv__(other)
-
     @with_doc(Quantity.__pow__, use_header=False)
     def __pow__(self, other):
         return self.view(Quantity).__pow__(other)
@@ -249,11 +238,6 @@ class UnitQuantity(Quantity):
     def __itruediv__(self, other):
         raise TypeError('can not modify protected units')
 
-    if sys.version_info[0] < 3:
-        @with_doc(Quantity.__idiv__, use_header=False)
-        def __idiv__(self, other):
-            raise TypeError('can not modify protected units')
-
     @with_doc(Quantity.__ipow__, use_header=False)
     def __ipow__(self, other):
         raise TypeError('can not modify protected units')
@@ -311,7 +295,7 @@ class IrreducibleUnit(UnitQuantity):
         self, name, definition=None, symbol=None, u_symbol=None,
         aliases=[], doc=None
     ):
-        super(IrreducibleUnit, self).__init__(
+        super().__init__(
             name, definition, symbol, u_symbol, aliases, doc
         )
         cls = type(self)
