@@ -1,6 +1,5 @@
 """
 """
-from __future__ import absolute_import
 
 from ..unitquantity import dimensionless, UnitQuantity
 
@@ -17,4 +16,11 @@ count = counts = UnitQuantity(
     aliases=['cts', 'counts']
 )
 
+lsb = UnitQuantity(
+    'least_significant_bit',
+    1*dimensionless,
+    symbol='lsb',
+    aliases=['lsbs']
+)
+
 del UnitQuantity
